import numpy as np
import matplotlib.pyplot as plt
from math import sqrt, pi

# generate a fictitious end-to-end distance trajectory to be used to test the optimization algorithms

def _gauss3(x, a1, b1, c1, a2, b2, c2, a3, b3, c3):

    return b1/(c1 * sqrt(2 * pi)) * np.exp(-0.5 * np.power((x-a1)/c1, 2)) + b2/(c2 * sqrt(2 * pi)) * np.exp(-0.5 * np.power((x-a2)/c2, 2)) + b3/(c3 * sqrt(2 * pi)) * np.exp(-0.5 * np.power((x-a3)/c3, 2))

def _draw_from_gauss3(x_min, x_max, n_draw, a1, b1, c1, a2, b2, c2, a3, b3, c3):

    x_to_draw = np.linspace(x_min, x_max, 10000)
    weights = _gauss3(x_to_draw, a1, b1, c1, a2, b2, c2, a3, b3, c3)
    weights /= np.sum(weights)
    return np.random.choice(x_to_draw, size=n_draw, p=weights)

rees = _draw_from_gauss3(0, 11, 500000, 2, 0.5, 0.5, 4, 1, 0.5, 8, 0.5, 1)
bin_edges = np.arange(0, 10.5, 0.5)
hist, bin_edges = np.histogram(rees, bins=bin_edges, density=True)
bin_centers = (bin_edges[1:]+bin_edges[:-1])/2.
plt.plot(bin_centers, hist)
np.savetxt('ree_fictitious.txt', rees)
plt.show()
