import numpy as np
import matplotlib.pyplot as plt

from plot_ree import _mean

# plot end-to-end distance distributions with uncertainty computed from replicas

def plot_pr_werror(fname_prefix, n_runs, bin_edges=np.arange(0, 10.5, 0.5), plot_mean=False, plot_label=''):

    hist_all = np.zeros((n_runs, len(bin_edges)-1))
    ree_avg_all = np.zeros(n_runs)
    for i_run in range(n_runs):
        ree = np.loadtxt(fname_prefix + '_run' + str(i_run+1) + '.txt')
        hist, bin_edges = np.histogram(ree, bins=bin_edges, density=True)
        bin_centers = (bin_edges[:-1]+bin_edges[1:])/2.
        hist_all[i_run, :] = hist
        if plot_mean:
            ree_avg_all[i_run] = _mean(bin_centers, hist)
    hist = np.mean(hist_all, axis=0)
    hist_std = np.std(hist_all, axis=0)
    p = plt.plot(bin_centers, hist, 'o-', label=r''+plot_label)
    plt.fill_between(bin_centers, hist-hist_std, hist+hist_std, alpha=0.5, color=p[0].get_color())
    ree_avg = np.mean(ree_avg_all)
    ree_std = np.std(ree_avg_all) 
    if plot_mean:
        p = plt.plot([ree_avg, ree_avg], [0, 1], '--', color=p[0].get_color())
        plt.fill_between([ree_avg-ree_std, ree_avg+ree_std], 
                         [0, 0], 
                         [1, 1],
                         alpha=0.5, color=p[0].get_color())
    return p


if __name__ == '__main__':

    plot_pr_werror('ree_seq11111n1n1n1n1n111111_T1.0_nstep1000', 3, plot_mean=True, plot_label='$n_{steps}=$1000')
    plot_pr_werror('ree_seq11111n1n1n1n1n111111_T1.0_nstep5000', 3, plot_mean=True, plot_label='$n_{steps}=$5000')
    plot_pr_werror('ree_seq11111n1n1n1n1n111111_T1.0_nstep10000', 3, plot_mean=True, plot_label='$n_{steps}=$10,000')
    plot_pr_werror('ree_seq11111n1n1n1n1n111111_T1.0_nstep50000', 3, plot_mean=True, plot_label='$n_{steps}=$50,000')
    plot_pr_werror('ree_seq11111n1n1n1n1n111111_T1.0', 3, plot_mean=True, plot_label='$n_{steps}=$500,000')

    plt.legend(edgecolor='None')
    plt.xlabel(r'$R_{ee}$')
    plt.ylabel(r'$P(R_{ee})$')
    plt.ylim([0, 0.5])

    plt.savefig('ree_errorvnsteps.png', dpi=200, bbox_inches='tight')
